From 80af49cad40295a2c975268428d7cdcb1f968038 Mon Sep 17 00:00:00 2001
From: Craig Ringer <craig@2ndquadrant.com>
Date: Mon, 16 Dec 2019 16:03:04 +0800
Subject: [PATCH v1] Build PostGIS 2.5 for PostgreSQL 12 on EL-6

Includes a Dockerfile, wrapper script and entrypoint script
to do the build.

Restores proj49 as a dependency, since it was removed upstream.

Creates link for PostGIS 2.5 on EL-6

Patches PostGIS spec file to depend on older proj, older geos, etc.
---
 build_postgis25_el6/Dockerfile                |  31 +++
 .../entrypoint_build_postgis25_el6.sh         |  20 ++
 .../epel-release-latest-6.noarch.rpm          | Bin 0 -> 14540 bytes
 .../pgdg-redhat-repo-latest.noarch.rpm        | Bin 0 -> 5888 bytes
 build_postgis25_el6/run_docker_build.sh       |  56 ++++
 rpm/redhat/12/geos36/EL-6                     |   1 +
 rpm/redhat/common/Makefile.global             |   2 +-
 rpm/redhat/common/Makefile.global-PG12        |  12 +-
 .../master/postgis25/master/postgis25.spec    |  18 +-
 rpm/redhat/master/proj49/EL-6/Makefile        |  17 ++
 .../EL-6/proj-4.8.0-removeinclude.patch       |   1 +
 .../master/proj49/EL-6/proj49-pgdg-libs.conf  |   1 +
 rpm/redhat/master/proj49/EL-6/proj49.spec     |   1 +
 rpm/redhat/master/proj49/master/Makefile      |  17 ++
 .../master/proj-4.8.0-removeinclude.patch     |  10 +
 .../proj49/master/proj49-pgdg-libs.conf       |   1 +
 rpm/redhat/master/proj49/master/proj49.spec   | 239 ++++++++++++++++++
 17 files changed, 413 insertions(+), 14 deletions(-)
 create mode 100644 build_postgis25_el6/Dockerfile
 create mode 100755 build_postgis25_el6/entrypoint_build_postgis25_el6.sh
 create mode 100644 build_postgis25_el6/epel-release-latest-6.noarch.rpm
 create mode 100644 build_postgis25_el6/pgdg-redhat-repo-latest.noarch.rpm
 create mode 100755 build_postgis25_el6/run_docker_build.sh
 create mode 120000 rpm/redhat/12/geos36/EL-6
 create mode 100644 rpm/redhat/master/proj49/EL-6/Makefile
 create mode 120000 rpm/redhat/master/proj49/EL-6/proj-4.8.0-removeinclude.patch
 create mode 120000 rpm/redhat/master/proj49/EL-6/proj49-pgdg-libs.conf
 create mode 120000 rpm/redhat/master/proj49/EL-6/proj49.spec
 create mode 100644 rpm/redhat/master/proj49/master/Makefile
 create mode 100644 rpm/redhat/master/proj49/master/proj-4.8.0-removeinclude.patch
 create mode 100644 rpm/redhat/master/proj49/master/proj49-pgdg-libs.conf
 create mode 100644 rpm/redhat/master/proj49/master/proj49.spec

diff --git a/build_postgis25_el6/Dockerfile b/build_postgis25_el6/Dockerfile
new file mode 100644
index 000000000..b80fd49cc
--- /dev/null
+++ b/build_postgis25_el6/Dockerfile
@@ -0,0 +1,31 @@
+FROM centos:6
+
+# usage: ./build_postgis25_el6/run_docker_build.sh
+
+VOLUME /pgrpms
+
+ADD epel-release-latest-6.noarch.rpm /root/
+RUN yum -y clean all && \
+    rpm -i /root/epel-release-latest-6.noarch.rpm && \
+    yum -y check-update; ecode=$?; if [ $ecode != 0 && $ecode != 100 ]; then exit 1; fi; \
+    yum -y install yum-utils git make gcc gcc-c++ rpmbuild fakeroot spectool
+
+# from https://download.postgresql.org/pub/repos/yum/reporpms/EL-6-x86_64/pgdg-redhat-repo-latest.noarch.rpm
+ADD pgdg-redhat-repo-latest.noarch.rpm /root/
+RUN rpm -i /root/pgdg-redhat-repo-latest.noarch.rpm && \
+    yum -y check-update; ecode=$?; if [ $ecode != 0 && $ecode != 100 ]; then exit 1; fi; \
+    yum-builddep -y postgresql12
+
+ARG PGRPMS_UID
+ARG PGRPMS_GID
+ARG PGRPMS_USER
+ARG PGRPMS_GROUP
+RUN groupadd -g ${PGRPMS_GID:?} ${PGRPMS_GROUP} && \
+    useradd -u ${PGRPMS_UID:?} -g ${PGRPMS_GID:?} ${PGRPMS_USER:?}
+
+ADD entrypoint_build_postgis25_el6.sh /entrypoint_build_postgis25_el6.sh
+RUN chmod 0555 /entrypoint_build_postgis25_el6.sh
+
+WORKDIR /pgrpms/rpm/redhat/12/postgis25/EL-6
+RUN echo '%pgmajorversion 12' >> /root/.rpmmacros
+CMD ["/bin/bash", "-c", "/entrypoint_build_postgis25_el6.sh"]
diff --git a/build_postgis25_el6/entrypoint_build_postgis25_el6.sh b/build_postgis25_el6/entrypoint_build_postgis25_el6.sh
new file mode 100755
index 000000000..26468ef7c
--- /dev/null
+++ b/build_postgis25_el6/entrypoint_build_postgis25_el6.sh
@@ -0,0 +1,20 @@
+# Some of the prep used:
+#
+#   git checkout caf2197d48ac8ee2fcb18a3ceaf3f9162c086aae^1 -- rpm/redhat/master/proj49/{master,EL-6}
+#   cp -a rpm/redhat/11/geos36/EL-6 rpm/redhat/12/geos36/EL-6
+#   cp -a rpm/redhat/11/postgis25/EL-6 rpm/redhat/12/postgis25/EL-6
+
+pushd rpm/redhat/master/proj49/EL-6/
+yum-builddep -y *.spec && make NO_GIT=1 rpm12
+yum install ./x86_64/proj49-4.9.3-3.rhel6.1.x86_64.rpm ./x86_64/proj49-devel-4.9.3-3.rhel6.1.x86_64.rpm
+popd
+
+pushd rpm/redhat/12/geos36/EL-6
+yum-builddep -y *.spec && make NO_GIT=1 rpm12
+yum install ./x86_64/geos36-3.6.3-1.rhel6.1.x86_64.rpm ./x86_64/geos36-devel-3.6.3-1.rhel6.1.x86_64.rpm
+popd
+
+pushd rpm/redhat/12/postgis25/EL-6
+# Requires patched spec file to change required geos and proj, disable SFCGAL and change gdaldir to /usr
+yum-builddep -y *.spec && make NO_GIT=1 rpm12
+popd
diff --git a/build_postgis25_el6/epel-release-latest-6.noarch.rpm b/build_postgis25_el6/epel-release-latest-6.noarch.rpm
new file mode 100644
index 0000000000000000000000000000000000000000..588a577e489358a3b9638f3b90c527034fcb8565
GIT binary patch
literal 14540
zcmbVy2V4}*vhR{}2Fb7_0VOW5faDC4GYBHf23XQAyF>wzB$AXM2uct^1SLw4oCOJz
zjR=SY$w@^}fj29B=Y02^^WMGpjlbFIe^*s^bxn6w&B(^n%_$NPa2+GDNN-6T(i;iG
zBPF4dN`%h;<wXP{`&W%y<;z5;eH0)NX$;U-2W~>!AE1mN5E1PO27W=r8~~;R8ssN!
z5THx43}8|K>jIR3R{;v>6C0k$kgT6zQdfWi<B@Cu6p$yy0+cA8n2m%CWN~-ON5yFN
z964n}1`#Ecn&CI4z3ELSFXN|v_@1vs^UKO4hiP)WmiADADv=_?eSC4zZ1p)h`lAkb
z0k=^cw}4CD2J;(O0;fo~nVDeY>N~*#Zp*LqjPH(XuKl2ccPv5kG#wW2KigD-q`i{h
znbW*poc<ndol<|c>Q!}H3&+#%S?ACnbl+Lc7yB(tP+VFoJg3&ba(MH3FN>j)nQ|Pl
zG5@jL;j5ZuS^+K6Z4U!+P;135M?C+*+19>SsXF6sf+@{>#1u-yn^KZfNo7=Umz(To
ze-;J!5HaJ)uWP^3NSmNy3n6Q7X8*j5L~Q%=B9(FAYalt3H+Ut<JDUzp{J9u}=pEG6
z$sdJfl?Jpi8Rb9X1i1=mVvO9vR0a58ys;Jaw_(Oih)bQ~Wj-`Mn~yw<9q&IYQ1o3U
zPo}-2rej8(xq7uV#$I+dDbR<b)O~>L!6)VneR9#MFYF>s;d>WE3~iAb6%b8b1^CzA
zxXkGmFD13*6^0oLd#vKSA4}cWRAQB?0?@x}FbBW+MoG@8q=9}qivCCvUtoC@Nc$^A
zQ_Yi9zIuvEZ=im)LHPbe7CmA^sOTA~lFYB1k;^OL=>jpdpGqHY`%&A)v@$4`s4OdS
zg+1bC%QHtwPomXU(3G2J;#19uD8}uc@PDq+a96smAbPQ(#EYzV=YXlh-lE2?+!e(-
z#6u#jLpB=%mr;^+L&>4!l%NPjIYqcUQbyj*4T(}#Qc^(3q971i6b$Mnivso#aLFP5
z(>~I>#&B#hq|7YUJg-|=6fwg3{@5o$C?DrCANpAJmi5cUxkedhHjf?W(1No!xYb-M
zMEd#pv*s_7QzwkMh?8;=+s9y!VT@vAWkcgn$Iq$A>1nQidp@3=rQ?`oMW2;-Bl<-J
zXgDiKSFbY`z18sj*+NyuRAEzAJKpS7#YU{X!?Z|}sho~;huhZ|d2>H@lPTQS&rTQr
zELyLB-f<kTD<beqSMPl4<pxrg1>Mkx@<B9=>D-Y*v@5-A3)$hkJvN?wm`ha9*_(+-
z)K#Hs#qW3s!}MLE^JK{%RBj=)bg8(jpOnv9eel`A#UdAe==2p%-NwI}dtz%QE7IS&
z$C0vLiNij8NvolwYV@P0hqKr9LjLB_re2&I7s%7%qgt&}NVaxp)@=-3u=*^8;BIlR
zUb&&f04bWWQQqOg6*00-fos|mFV2~#r%n8V3YL#IM3pf)p{+#tUf(->J#+8z;@#F2
z@}TVFzWKfL)*<yc-JT@=d)mqMiR#&X0o_)p0;c3Ps9AvNrDHp$4+ULFVr2_2MGjNJ
z3%s2#ckOf=UnjeTS$sG`E<92ITSTzttr!|l%+frOapQrnAY48uZPnCOg}1$rc6;ne
zuRz`1FM8*gY1SxfUc(`TTHvR`!39|&S@!e8n`s^b#u+7#1x1soUr!pQ-e>lRsVs`r
zB3T0s^!r^;5%F4VzH_w3>`C{b6$H9;9oR5`V%+iZaSG4|ViE}Sw>YQ)0?`fuT>vG-
zG1?Y@5@Zm-O$pqD>#w*6#6b}8DP9360W+LpLL4Murc+FagH*uHa*8)jvBfFg1Sk*}
zLGMm6Ax;wXKc3<pfCBtK;hHf2?g^iWphLi4Pw`*l@10`7Q~r-rEOv_b0Seedq<D&d
zpYqL5@!=^BIK@Y&IP?S)rX|=%6m^OTegH5r_7oEYfSdT!Nk1uJEkG(GCd>=8NeR9H
zFbP49fT;lrv`GlQCSV$X0{$i;*h|2KJOp4;-&0J;LxB9BJVoFW{7&E}o$?9e5b%>z
z%z8>+0u=BUDH}iu`U|K1>;NUm6Z`<Ig%rqj1U?z~w4d{Yl4+h|u2cN>6!QX<AWzUI
zjL&z{514j>`A_lb{vZ_tFu)`y*h!FA0w|zQPMDV-Xet8~u!r2@6kj;OlrK&(VGjfP
z)P(0s(APZ0$EVl;pul)Ez!-o0XLyRir`QOf0FQ<+FE9?N13(G#ngAuN-w~h$K0%Lw
zodHVV6YL?#Uq0n~oMM+#+yqdd&LDL=>8B<5m0%y@6my?q<S7Q9V$>-XI>p|nSmYEF
z>JeamTFsMwQo_C@V1nHQdjbIp*h`BAD6p?cgHHK3Px-;8_`wNgNk7F60434^{k^^d
zK|x9&y<mSF3~T{|d%@h1crXfs1MB(vBXL+98jl2<pnU^^!8jxqgGc*ga3Nqg#utTl
z55U3v(HLKljRzVJ#-8XBSpG1yFCOggfdv0gh85GZ&@&PL+vwB=76xE1WC$3B2L~a&
zy$STcO!&vVkN_Vr%ohO;z(No(f20(!FpIlNk!}HKZ$zMvq>O?T)*~1qg+d}QI2aa(
z@kGM?r7$>mKn?`5%hvzX54JdAfc^y<SeOJt{<YIO1n-aZ0sIn(#$kMYkiP!X+CY5@
z^6>Y^UXYeXc>nuk(%1kuX@aw*LEZ!(f_yPB9NYsW1UAF?gME=m1QPLQHArtLVVQVL
z01giL-vem7A(6g-S9~ymNCdSI67GQk3krb=gZ=RpSW*%ULlE@cLjLsrRWE}D!Oqk|
zVBk_$2TLRU;nMgJ{E7dhaUQ<Xr*r%@B*Bk=2K{Rpm>^$o3=DC)7%3bQ;Q{lPf@6IC
zxfrOlv#^$xj^Y1oCXf&wuu>8Y7L|4ZW^?{Coisx9|7qMmRh)%RG@Sn|+Zp`-*8KB$
zLF9e_y$YNQFmOD8JV*#T24j&$C;zlIB8yJsPJS)!D(?K(TPc!&p%5riRtbf2lT&~y
zAR)>yH)VOa3<N1F>!zSA=cWh)ysrp{Da*<rW#nLPa9OA#5(PubDZ$`y6bz06Da*(z
z!4#pg5M`t+N={Z;5rT4q!XR$43Np$vNR)!CEF7*V3q``*+~kxL;3y?o1tmE^L>Z-|
zB%`1p2a=bAC_|Ls2t^oNPC)?*g()JT2pNd7tUO!}j)KT4%Ru4EGD;{J7(x*Ru#}YK
z-B2h5Qb7iy1cO3kKyZY-GB6t)DK9S%kx@p<1L|^6MI{&tDF^5(LFAE0B?Md<iIi7D
z0yE1a6cpeH1%!+Y1ddX0gM&c8%78AEo0}U7jzGZ`6@U|^1Vh4M3UYw0NR%uDfs{wd
z$SNZgP$*dixPlT&770~Ql9h)l$jB%X0^h$}gc^Zx6E0#L2ICL<|NQxT6eGMPO5t&E
zDIC^^FfdT>{KxC$Ac*~4RUGtpL{R?o>c~XcH9(97(E<UT`tP^28yYx99-zPIe;o7V
z-28PYL4aA_Xg4t(j1Lxv!~?rqAMK4agZUuw;(zf7J-TQh{QCd1&jJ=gIE(}q-Vhdu
zw7?-z=-_{-oU)DZ4p+qiO9^kvP>`IIjFh~jEJ$7oDkbxW5`Gn=Ai(dR>m(-r!!$rp
zNlFIbSY$eMm_KpWG^Z8QG^sW1FmX%iFi~XCG=4MIVN^J$X&51|sZWmh$F28czC-W3
zW``=?ALilf1JgVi_;0~h9V`hZ7<CZ|Bm@g2kWlbIP*cU8wlx14Tuvkv|HqP0kSQAO
z0Rw`eHDPiuB>2CxLIGrr^!EVUp%E}|K-eqrPXp!;{=Zl)57I^Y`U08F0PXFA!2uH>
z{$Nd503Piv6@Wi6S?+%(Ci_=5u{!yx0i+RkG>`yrXkT}*D)6a866x!%>5T>+{=cV@
zlbIkO8;lQF5Rb+93xaiE-rlevSO{3vAAZvOS7%De{=18OV1FK!7gE#R2L>zxi0UU}
z%lwaJ<t63+7qW8y3t7njLRJ<e3D!pkgKe!$z;0K;LQ0A<P$ekP38X|Y77K^UgZ(jJ
zcMtd#LcT@fPdR_mA#fC>ePD1L1}_B&Na6tuM&SV0o@@jl%@8u4B+xB+B6d2LTYx)Q
z2nqq>Ibn9fq4!3^|JpwPI8Bn^0H9*>LHfghjPC^wz<J}rzCg0~LE~^39N__jF}{Bc
z!Xy0yuqUOKi6oR-5~v4)2z3uIxD}F6#{gpkbr>Np<AM6(-?piA5ZVhZt^cQxxgslj
z#T16eUpdi40Am1g0t^@koIE7hALb79Xb1RUflQ3{1tXAwz{vqTWM!yl0)|R~#q5z_
zI1FImkT4%{DL`1q1Lo@vNF$JVI1Y^^6nbEoJ5bsEG4D@R0)}G=g8@~ce}FGwztu^x
z@~84c0TJuJmL-y4ATR)j4k&MYG2lR$cL4HlItYSe05b_y5Eh989zq}*aK|5?L*(Qj
zas&tc2b%zEfPDbid0Gd8(Rh3S5>HrxkuTaG4V?AUs`ek@`meA}h=o8{|G(bAdjO%f
zCe+=35&}?npIoPTf$~qd{pZI?!dL{If9P3Rm`Vb*tfaA?qa>lom4t%+W#64-9)BR@
z17QFtwXm2!J^yU|wXFbEpe6<V*}quesS`G*JJwzLq=&GhPg+2I^+y>mg#da2@Hik(
z!Ei`v1P1<Z`0rUy5-JUnG>3rTSTqI{d=&&atyF>e{~U%t)vKhtFX27pzq|hKQ-Uvu
zKw8#1Mn+(NWUxO7fyM!aIPebf-;MI0`GkD@=Uc_`@oz#=$9SlC)!`D5pXYwj77&93
zh=7+#5UGVB^wXsXLG{ZZ4!UVlH^@N%&Gm<^43^}fJr~#SnYb$H>ww>9#ly4nZNQ{^
zRx$U>5Exs{{2ENZ&4rgt4xS551)7WGPqQ@{?uxLlw!89`ye$}}cxBHxRQt?UCCi}O
ztkZ7VQt)f$lgswmpSlagk`);<xLAH`d?yBde5CVEcH>PRIm?*wkGJ#}2i<oc_k0M_
z&kW>DyP8OQ2PuH$DxO%xI~FyuvVZ^jZWk*3*!9zs((I-?UA$aaqU)ckP=!K=w&<Ih
z)%OzEq=i3>ucW)0vE<{PcAg1HV4zvNIKMG<Y4$^%<^Z#4$%1~#Xr7qe0eGw(TxRO>
zrkoEwTy>^{A(h9g@qx(m^}suZ`IF>~zSl_(q`ZYA&l`s+?Pg0VEFBgeFqBMua>%7?
zV#>mQvx=1oVBs{6<7-h2F;wu7w%?^|DSp4^E?pcf*CGC8?MhtMhkGjh^P9^TUP$=F
zeb*=bpgoWA<O&Uf-EZ<vaU~NOe%8-$Wq@|pRu|JeYuw|Ov>_Pw2r3#<-1a!;v6h3x
z*7Cq1rI&~+SB;3`tYtzz=M|<f#+wZj#sdvG0$rpM45<n;4!Xe=DgiPk!Z2atU-JT{
zak{T;1tvXmTYOfEFE+2Rl^;XULHmxS;)#)SN%4HKWR1FyjdU)FO7esSR_3xyJK{6=
zAB|7QxUtIOO!+3-q?MAYbcUTmO>@I&cMz?V=HF=3-QiA+DMk%(lKLJPsW2k7fQItG
zUhfX+Kxq!%)v{*YAHQx9U5K4{xnOoqneL};N#>Bay){HD&8elN%X5ETbK;A(JLlNe
z7e1j!Rlat?<}(6j*s{A^QexrhzC&dbF7$S4F+cc^bvTHAXS`?pNunSvyBQ?2KUTk!
zks9q^*A+j4R#R-+uz5bgySjJ#YSvDwL#DIV-F^=J8CAurj^Pb)Tk$D68aIF3$}6P9
z>rT}_GbS_peA8%Srr5r()aQ5q7}b($T(Cdl)!9!0$}~?L)7Q@^P#Z(iXA-6tQ<4+=
zNGXUr7=sTTHzHw>kwJP-kwGH8)IG`Rbm@)Qv3^GSCj$d?2aL~EX^hfpzSDlK`=Bwu
z>pO5Tg^nDUI51+)y(GO8SVvlAeTFMxTY2yBTRRytOyL8~Ti^GLWRlp%m+`Qp_oVN<
z9%kfFvA()2b2$yeDBqmfG?o$VTNnFzjc*JrzVmw;diCW}*i~e(`zvgWX673YNLPut
z06dMDk>gcw;dHc&!-4AUtO=B?c|X~4Mw?6GL8n3W=gSwy-##GWl0%zq91wqb!}s+D
z6&G3V?rVv@vzM!8lj<*ub?V;KlczpAcHPJ#1+TlNVJ@J~_w-5Z=U3^F-CO8zTi<#8
zO)3aVi;axP$5nUOm#uhG_}B74mJn;hHK%qsmG;QB>#Dg-H5C%CQ<NLA;ha*id%kr#
z*0sh&9kkB1F|zt!U2^^SYSXGA*YA$%_0oM*4M-Tk1SKB{w9HM9GShm94AJr)3(Z|f
z)`LFlZL;fGuNPNT)j6!ErSSk^-IK0A!<9sO>^oBw+fx#YcNh0kyJJ5te7oaW%-8*G
zSk5hCt@!@K0UFzzcVoYBH;QAU#iq~MXiz?)3SQ)1)-qq)h^$%KpE1wlDo<^$QG>5M
zhLWiu`U5RXBwk!y!1@S;n|w6yyL{aPVL;ox=uWosWPP>4k6wSLZL4oY>#|c(!K$Vt
z+*G~OmMdw)HQ4g0LT(I&pGj69r<_EYM(@EjoZXIoL&RRS<jZhs2B!Sz#|yEqX)kOK
zDT|qw<K;MX*i(1Qxb56{BI=ikeV3BGk-J{l)Zce$gG`gdM~n5J#@=??+S~U>cu3@h
zShG_l$y1E&OF4H@P*q@gJ|@uJ`mLOk+V9<yp)eX2kb_*%l`1US5|WXhG=GGwz1>hC
zKgbi0xkDk;xAR~%IBVc~$`2{VCvie`qTX%{^eYa@G#v(Obi-_U82sot;cK9vW-eNN
za}yDMCW{@$DM!Tz#@hplbbBZ^ZVmd>Y}Bp3DHSuYRXG)?oKG%>qA_gE?rrAvodqHK
z*534ejU~5Bbq$o$C6xm@%yIp9ll{LcmR`S1%E9)1V3foSiMc6tRr(AikApr-De7g?
zn;KsA-9y7AuRRMI^R4?!M^=9FZ_`Ao#`Gq6C!-S?Bl79&yUPzBDYGUuc0Egx?3ROS
zS+5ogQ-U0+9QH#xKT3`f^$rz_Jn=n@)V2-Z5x&w?q~-cS{=47J<~{6o<y@jyu3xe%
zeSwdjW>u;m-?_0C@)Bm=a3afRX_7CF&tlZJ2h@qVSS=sFKySOs-hS(RfjOl2gXe=m
zmF6f@r#0J1g(%w#`WrXo1&m)Fem(cO&w)%N=Y#f_aYnO8maO2Sjmq9E!Go!FwQodT
z;@b958$p}ZMY>VeeG~UPh56za&xn$kSytI1{m89os<cD=Uv3Ybv!B1XezCbIaSR0=
zc-&7cs1mSqXN0a0^RrH`fOv54Ls$GRXKwp>TDVKs{fgs@4yIrM+)Kys;bUhhwg}<y
zIcW;6%5{2F-Z_2Q7QO8@yh_PAqA*2`LCfTa+;$jFx2fvi!*C}o$Vx&<k%Fdj9C^Mk
z?HV8DlSksTT56YG4YygcI74i&o!iJz_6^#W34z;8c~JUGedS{J5qi5BD?Ia}X!P+z
zis%+@Mrf08)+@<bC+V%KXtlQSAHj7ps0FEB?t9nj_l++YAN6ghT$^2V$zizifNZHb
zJWg^^dS#yR{T>&r0kwkD+Yt?knqGfX2)P#eij6b-mquvPF?p<9(@XxT8*sz(<Y<p;
zAtXPjGM{dLsv#*YUvMo%rSi4hU#cpj<+%qY^_H;|=-%6|Nc*ax71*oImGtbI{z}2M
zz!4^Q6Kd;N<$GF@N=G^9z3AbrDzg%V%e$!?!e70fIy#iv|ERn)7Pb=?I~!8^Ax7K*
zrtKU+x1_meW3=9ScGZ!p*)1V!UI6p1m+BJ@^wXFX?8;ExA`~lHb%u7K_$9l21gQ^6
zi@)1DHn#hSv%3M<c8Q+5j_*NST#hEM`)pa6_lX6E>O$laEMq@T(Jtq2?Vbzq$_%A9
z^RB+7oO|Bsdk?thi<}{iB{`dm-{O_8f(L@09q-&PRDN$u9;Pc_11F!YPiOOl@8ut#
zsb!VSuf399Ip1W@OHTIzo$Tf0HDQpnKL`AmZSG<%><#&P!iWuMG2rXxR?+Hb5>G2s
z_isGYH|K5o{rdfA<@}&*2OrOVQ@}#7>5@BS^lSxkY+mqcuehd4$OZ*nf8DGFO^=}1
z;`fK=lPt>L<iJ1KY|>3dC}*!c;V7DQo7i}@8@%B5Vmf}Qxmo;tHHpNrl_}qsCwKU6
zn3AKbwy#w7-XH2t^Zr(i$qF2M?CIyF4=-fC+NjFJx4n}P(81HYTFoSWmL6}#_3$py
zVVtPmYR|XJuKr{L6Xg5><wST+6@7;1eYv^v?nG;ywmRn@OdF0*$1iujeaz-v4U*cf
z&Crd3-H|ofwt4w&jejUlB&ez{kdY%p>tjJjeYlsNeka%9#p&1UapZyR9>1?v$qKwN
zQ)8c>;&(}(>a&`(x7gsUz2bh!SeYY6SN=y?rrMP(w)y)>wn4SeS}$7Xm3Om{rO48%
z@OE(#yX!h1u6=8M=*u96e-xAl$KhU9KnL$z;yiie9v-!4+~bU5b1Y#0G(BN5c`Y)+
zp*haGVc9n<O1be2-Xp29sbEkrLC#O=$|q=2tf~G$F2sb!L@rC6SmK?&kY!IctRqq)
zekak2$rUd*wA1`P)yRZP?m$<ED_HV7Z{_9dGX@UCJ>)j}F2D5|-^a&9CwO`))oZhn
z9;awfB{1`;pL^T36>NA}7^$xL5}|?=Sb6!Kn7AzI^E72z$!<F?%JCZgPr;yQPAOtD
zc1Ltp!r44OZ)v{54Gs3flDe~QKd7VAg7&iy73&~4%5q^X?ZQHFCLJ3WgQxl{-#vrG
zAQZd>6nmg2gGcU`D0swWlw8y%aq+B0A17sCTtwR5(WY0v#$p(b+oOW~sqB|ktkopu
zx$6Z=`igPV5q1GeDZ}##GBlAoD;>ma{#6Cjdx(NVjTip<^53Vqoj|!R&ONQ69kp~1
zEjJ*ExGlRG9?2gbSiGL~=wg|q#=Q8qnlnz@z0@~I2iHGoC!W1IlcDuADB8lHI~DTc
z?VIym(4t43)tPNM=^B1xIrH<pPUnf9LeD;ov>s?2=J4(qWG!FXmAN)>E5V#6m?otg
z?C)w1NmRex9?IbJ_|eU&@ikDig}oSyROHzy<^8^oN2`&Qb*<@N$5SSsO*^|=j1c7=
zv}tlp=MM>H$SzE{$8Z;$Y<S>}f5LqEK7PKt+%;px$RDIRv&bA!A8oYcLEIZLDfjeJ
z&E;1m1yZ=SS}`G>2V0AkABSy9O_~Q^M6gcX6u2V$(C^FKCe>qyd2NbS^l(C8IV!Eu
z1-`ZI^7ZF6Mb47;EaJFfIn{jq(q&tL4)BNRsDY&To@Z;(Hrs36KJky;)><QqTEjjD
zQXIg(<OHh0hDT|wJIr>T|8QvR>dU$;N5kzAWWd`>AE4x<Hm@skeS{lnvDJ#oS}3?g
ze7~7#`|SE*5JV?*2APPzpzWO^+-#gb>txeNu`R?#_Slq0z1_lRrI!MGh1a02E0EbR
zs?am%E5qfr0dx!I)q?<cL~jGTTDC~(X#HjA6IuPOfpmO(a%v%~M7}z^h<4|P4}Awb
zYc|>%5s@oC5%HWJ=DS#<kb9F|!WODF9i?`qV0br|b!Kt!wK<bG%u)B`weNI-wH#36
zSD9-P4|kA)jIe#n4gc~Ogp^h0%u8ap3g6Dp?DwDJ)Hz*`%y++)Q#ht+ej1h_W-HkO
zRmKbZeeJx^o_&+7-UIUOJ^toK_V|+1BREdTZFFHoJNaxOscO@3UKLSoeBp{A<AaL3
zK5M*R$8zzt#oI^B*G9?%{c{2m#WGMNj}U>-%*er?ZGE5c*<}90O!WrKO*a{WyT@Li
z6Hyj%FQ`{vCRM@E1T5WB$nvnqR5FFLjT2kU%y<p?9+e-KZpmAWPY0QW|FVNF_*-vl
z*IoQQa%X($2m4eUdfPvn%h7HyZXHXca$TfcuWP=Btwoyb{fH^-@S9QL!QqQ+F|d<I
zS@pSU!#k)N)?<5T?`=+<yFI1jnqzIBo_Ds@Q@N&i5j}Y}%c#0PTpRc6YF<9==Q}@z
z>~QU6n+Xn9bmrWPb~Z#>d2{q4^j1$6RT%qTvYAMAVCe_r>p?{{!Y_3vOgf{6rFmO^
zyjLGMS1sM}B%NWBtTCAyef#O%*ekT*C_YaQ)<;4~X%rK--lDRv(QflvnxJQ>jrG(s
z2V)d#P1!}gpUwFwEbJZH&t8_#iRNio&MxRO_X5}D=m*Qsn(Tiv#1GRpGx)qrD_FZ>
ztrxubO<c0fhIfy{=Xu>L)%OoKhxoo7LDyTZWUe%&Q{o~uKlC;~7gpf04eL^}Uwk5R
z;S;n@X?j4EJUJBqPT~_A>ycSkkauE~Emly@(jXzaxQpYma-aZoXR;L0FVaEIY9o;I
z`d(Y(zM=f*-J9y|K}j0lnLIjp>#r!3nk`nCHpAU?4S2NT10GL4OeBle%o$*mZoxJ@
zUO>JL%=0SSgK&AWn8>I$<CpxdHSFG;I<pvd`F60{&wFQbonBG&D-cUMiI?AJkXRlp
za%XkwnZGb((_(VeQt#7RcrB~Jue9w_=jWhd8)obMqR&hoM0?}8YAzJr>(+Af6<aTg
zcHXKC`q0p>^q3c~;Q|(p`)vw;wOlfC{1zQjl!m?&^q{sWyON~u;L3ee>(vS~7gfg5
z@?Q76P{}9k{InEw&(mk&&5~p<rj`;awnJ+TjG3qnu?g-P7EwyPZf`BruanM*zA^VP
z;wsH|FAa%5nr|BqbUPD9XKHJy@Y7Renpd`+kG=w~!XL|Y<^`_;(%x@cI*D^2XUXJV
z4pE0sk9**ofyt?qI@$>9+$GfNjdx;F1*qy#|D!QDei?D|$uuo(BF!f=ug&3-VBfXP
z$Qa6!4<WryJo-)E31Hj7w~mV|8R7kW7x5!Z{isH5(3C8`Fhrrch%(_g5P6|`Ty%tv
z`N<5({kqwV_PTDN`QuWM!MO(vjYOZ7!|cnl8zKhOGw(xJeT30`yyownt42x5RT+M+
z>LtEl$|P#?<ZzzV#D>H<^BbID&AO4Ky7VkOP=~VF9#cT<nI+s*-htX$DZU`_p@JJq
z?_oPg_3;<lg_4XN<slg@oMeIv(;Cr=eznV7K*!+f)5D4UF3DN5g{sV};(j0cnx^e}
z<@BXA|C(}|Oa@!IB6Bw5{^ukIr3=v3*lBeg?~->|es_vTKfB36hS&O+3qB7<rr+uJ
z`?;W>axDI<sM1oj<_4YOp_%BaE_>r;=Od~dj-@49NujzbQ*t54{=^~f%R<lOe+`UQ
z*Usp3sif2whV6_5e<?<y``IJaqUI7kOInh<L@bSlZatL_b`)BZ-nY~nR`Ze{qgsLN
z1(dw_GFGtFO-fnr+ePxV@WbJoPNSXsZxw5P%h7(?Sp2olTqN`|<*-3RqkqPJWt~NV
zS!7sT^pVKJ{M9q$3vn#w1Bt?~*Pl%<-;PY4>){tEdvNoJwRFa8f?-GSPDmd~giBHX
z!Cc3JrP~l_;AQWPly}&+htFh-AyK$@N0&9`Fx|7vQIoJUfpcRtwoD5wD?Bgtf4|8!
zU0#VBx1XfeHv2~0Ec<=<mrH_Mxnm#q^pMm7TVC?u*NtkVUbM#%2X*+*7=}<m!A6$@
zJrxg@)wkD=@<`y;k;F{B9u=mKtCBm<;ngXb^2fUzl^0TyvTD;Z+kg2?4P24zf2+YI
zG4pjkf7HmoH1?KQ(WTbF*M@@@yoLp%h+Kw)EnU^oKKbGd8}K@BxqoZ+?y%({LvK1~
z=DanT{MZcfz_)66llwavOEOOTOnsXE{q7BY9%)scncu64?KK6?^f~uZMtB~i+`3eH
z-^uvA&U}YgQ2G2+e7;@uF1%(cy-;N11q;0pazVVvjIPUKZ{FDg8KEYG;z(tY3)h-!
zViKylZJl`usc!NUh2DqF6}Ne7>r+){GMd+th4xHS+?#R{ZRwB?(Xa{0$#4)<J$&br
z##p`b@=O1NT|c#;+}AFZPe>%|;lG5+XJ{_{Dok35w|rYQzbcW^-m{`1Rx`*QYG1wv
zA?6(GZV%<A^bl!tx<AI%-DSe?AV6hN$jK0=H)*@`;^*{_*L^O;6`q}RLy&?>Z=3!_
z_M7QdMqSZui-|Hd9yEq+0qUCtdE{yiT++A*`lZZF@msOWsF4Cg$qSLlU<3mU({JDS
zAfm|p2P^IN=N%oa&U2`s_)$BWM3Q)<Je<9roZ`V#E>_paYlfz25=Y;Jc6!f;9-G<O
z#+*~2CMI*J`oNp^)}*&LYW{YyngN#ys?|ho*08@o5Pvyb^q3OUQMR|8<x+BWT{ZQ~
z6=OM<!dloXmgtL))xmdZ6Ex+1ufE-<JDZo8n8h-~HTlAIIcjuC=iJ02$%vBJy>T%|
zVRtqS7Kw!pM2LNE+hp(WsCwb4nS`Pj9+}c3ZA5l3PK?3b*&mdL`4&A)RHFi|LCcUZ
zrK)dWXZPu4!~@csBHA?VcPk_LY?cLiTWhO76|=C)k5*9SE+e0xm9ermIM-<Q!WZi#
z&1ORqkN49X<-vMNBJVcbtmz$c#wuv94!*kux#A`76Ze?y18o(K>aPE_RH>=ZrP&m^
z$<E8~R4nhL+a$O)eX(Pv93g{fu`KD{cBlLuQ&azZKuyp&0|&D!R{E-bCM{TZC+mB_
zg{yV>4e3<znbjNF`+@Ay$Oq{IiJ1ao7E)^r6oMQt7qJ?2A1`PQNvDo44@pJ_Pf*Yb
zP|iRqsjSI)%xHX#FzlAzp+z65A4X?=Z!eYDfV{ma6kQpaTKF{_r^T}6bW81Lh~2r3
z#nNG}2jBIp3XFvK*x(US!c_NNu=X@#S1$D4lCySr&aHN|TpyN5ci5k@8zE%i=w67z
zxb)<8-Yl~Ds1#fzkUj&J`<9y;`iVZl>k`f9%en*I6ycYDa<id%*%!$y`6Ibk)-*@-
z58k2->K;f5*}F{g#An~n6^tFL&fK1w7eZDEZdgMwn|DN^Y#D1!-_|c7=``6#cf;16
z(&g{jeM^6LrsI&)mT$IWf{odGq0`~QR_RLPlbkNGbk$Hrl{uZ|-Z7hx)ePYnaWS%l
z@M&h+shSNFTzcwc!b`m!hfzy@tu)IX>h~n)7__H$9NH!>!i<!K6iD_=e+?ZPQf`Wq
zeLN=r!p(kAq^AT5(&@Wf#__gmeKOJdp3N|Yb{I~&1xd%hk%<$*av4VMF1R)37^|W&
zqOnhnUZ!LXi`G2|)4ipl?dq;iNdcxPcG8_SiWDPn&(N56PoVatyuUFJ>GPNomf%_7
zAj8*-V;J+62~Hn<tWL*s(_DX~cWlo_c5Tm=@eR{-i`7~~Tu1raAR8i=aON)?GW}1<
zY2*?r>BQ$09x}1A$#bynXSRB`gxf5pdZ-2@`?au-FSE%S4dSaHYcV+iYAZH<oqAXt
zPim>Pjf>3K$W<zy6{BVuhv%u|9=ATsNog@VlGWRPe;5LMs9tm~eh@o)6zWCHF$-2h
zNIj3z9J!Il2-Ug}`Z?ckY%i3I|8tDS*udSKr$lR65ldyV4daRd-D2zq^@=$TuHObT
z(e!p#bT(6+v_;0IYB;16yAW#k`9vpQUkwT7Btw(kj@H-l<zW9Tvs74Vb-p3vVe;<6
z#m)x}la6c@M9~#70b#;FN_KAfB6^A4<pSr*JHEYbM?UQ~HLxBm=U3i#hBBOYdhxa-
zXz%AUP*LbJoPo{GOAKdtYcL~j3>33@eJ1G^6(y-UadN!gt)sj<Z)DkBx1I~`&{7(6
zoz)5;pNbeeG?{9QG-_FCI9R>^0pFak{H8a3ZSUu5j%e8a@+GYL^~=FhlV%T!4bs)k
ztv^I+Ts&}Rz@by6J$hH&cfg)=)uC>AEO+^*6d|h(RvgL<Vx|y`*&L<LTt3`(jw9cC
zCRpUWrlo~wlzAMUdsP(l&8X%5Gk>82S#$RLm$zr#3NP+ugujF`u%<92H}F4TLcjOX
zQWSNZtnivXo<(8cf+;Mtou&a^ZBa-4KmAH}1Vv*LJSi=r*7DmgjVI!fOU>hjMJykU
z8zx0<#iUceB%?65eQy^JhlaS=%dm;Z={=5R{b|U*i?Ir7NI5^NGNbS*KAu>c5w-e*
zW%mv;w)Ka249zCHYx$#_@67XFebcd^pAE9KIHs?vg%oNkW)z6FZw_zg#k*FD3i!2~
zjs>c(Pt7%IyLG0w%IVR&<{%GgNfJ2Le}<UJbf=Wfbr_e$6lL(V6f6(7WQj;~l2X+M
z(?3V9P=VFUdyEHVzkGe3rl_-#QPs{`s#@-LQz`CKEPEaE)%mqaO7X*smcMU{HUxM%
zQpWgo>9!$fg%DwFSEJ%a3mA&|NL`|XT`vWRFDRv{yT<A<U+HE=C)|Bq*BD#eC|hxS
zV~r(l3orHP#Y3zbeT5^H8`FI)ae2lxUR+dTj%;Z&buM}fql;C)eJ~}@w14H2aIryn
z2JIUc1<w#kwx#<={p3p_V4dPiw}9{D?CA3CnJBxRDGJ1~t&@eR36@-<`#lYH`E!=C
z^HhBLh97iUmo5B^-h_l?(Z7xQ)(}VSOm?4mDao^iR=NKk(YpbOHp#P)b<+Ou&3PK6
zC_4GLOlgn{v?C%lcJQ%6`q>7*>z)fYDxcb<x6W3hE{Dw7M!<7pOA;i<DU;1CtUqfp
z{A|(erikv~&-Qa6_4nbJwp5EcLEDMt<H|Fs0<Hs5Mf>U6ZZ&jSWkDWlRCHvV6(vj3
z5s_dg^=HPAUIB#+CW9u{tP8iFkeWB{#Mo`UcW!)=0+~2}j}q2+x8ZTF{+2$4C1s5K
z2cOu*vOzbeO2+d}w{orTc}aA$69+p{+zw*zT#;S*H9?cjczuZf9O%Z_^;DiWcidpK
zQ{>e@#9GX!R5Yribo!gJouW%4(K2HWM$F}*vP$ZPKXW&mI_P$v+sCx9o*(HztkodT
z%kbV%s;?Jt$Xgqr`j{QkdH`?F7yS{meo3fn_=Z@`i$=d6Ee#2yb(dpG7BbnLxYp3z
zKOObTC7v;b6}oP$StQEm^H0B{+pr|A$jNJGt3~0}_!}6MaHJc27Q^ywono^VYQkT+
z9(9K+PT%;QX{YgtJSwCTT8qxE*$So$sVWX<@e_>^EKJs$P^P^2`>jmLH_@8->q`UT
z%qAv%%vDT&5-~S-OGSz_hKEDmJ>2adU^(FYc&6KQ`5=2U`^Tmel{(8j%|3H=&9s(x
zW=db(CGOA?*}=&YHfM$||D>QOt5Vyj($ba#bB%&)Pjc7`evULpXtLcR;;|=-Y6>AM
zCULCQ7JXD3Fc$-VTcB}df3Aj0^ie7=wYWh<$nWz~?TgAi!@`>3qlbqeYyL+S=k@V2
zuio2ia<%^A-)-O=bGP?^`8}}m9KHBx(W=-e>V8xFhi_5BY!A;czNO3<S~mYI+X}7>
zL4OsKNBCTECUfx7F|R#r{9+Mo5iVkTYxI2E8(h2bGh)e2*_T{0XKz`xSGecCkbbt?
zog%X-@X=55=3_ONNS}A@uSaY<ZuNw=wK6sYy=$TRNyjM@Nf#kF^J!+LeymUNfqP=&
z@9g+HQeSJ%7x2Di8c(XY96-z^<ce{*c7RRnk8OeYnm_jB?_a#=ItvLJOq+ykZc;Jr
zMia@I!n#6;+PsC0**rJA6v0jHvrmokA9VV7zB?Pz^L#>|%y_0m+DAJ+)W5(-b*%DE
z_3Z9C^p5>#Tl0;9%H3D@p0L|L45{l)kW_DQ6LuFTaiv18Ot)5#2krY<dY-vM-<5@>
zjx`L}p}90W(1GuKvN>dW9d9_Mbh90?Bx#^nD8c5^I}!a=TzZ5u+nG&G@nb*z<VC7a
zs=J!_@r52A2`>`!*bcXYWF19~g`C6@x$$}n4=r2HyOx@+WR>oQWh5>$HKFf+l_Arx
z@n_R>CZpewkrm(ZiEQw;RXkRm7fJoO*gnf)om>L%6~lb*YR!p}jv^Hq7yETaTCqXy
z%gahkmoB+fY||3?f_@J>#Q`GwQO`Zs7m&;i_1}FZG=}NBIgdk35#(E;VoBj8!lp{%
z6fMj~i|<H$&ro+aI%I58a#1o1nzPwZc!az*Hc}IxyTMpsmh%4Ux4P?wT5-W%@&VuZ
zu>o959d>Pr2sFH7a%P6(VG29HvBR`cXxKg-GMZKkp*Y9!rJS7clX<mDiVCrX$TizZ
z=M=A$ImF(x4qAwunciY;9Az0d$JXsu1Br0Ef!GW7iM!2A6}GOFf%hI!9DU64%X#P#
z75@<jVSghR#%8vER^f%Xuw`R*KBao|6BV8}#bpTELwo3A4OsS2L<3v+OGDg4QEP-_
zRWq!id4|qjJpFYCNxH2=Z?&=g3(JhJ)7bZI-22Ujka=q3PKq4WUp8EGxwkKSxVLnc
z<<~F9zDX)^fy}@wpfO~^hS7^`?YZ23?~R8_SfRQ@oSOHHrQR<d(wXxObrVTm$O?#W
zZV#EOKYl*kB9JM-@}>RTXN(=UWs^kalwJMsE{)bwZ_dX7sUT)%1qLneQLbeH5zQ(l
zSkEqWne?J{dsKbq6)%gW1zUWpfXP`pZ<E>fC87;u;BQGT1{d{i*VejPN?H+hJ@i%c
sP`@P@FtTdgEH&cAP!MqeM6|1Wy^aXfC;pVEer1-2@CPp-YR60e2R;l*O#lD@

literal 0
HcmV?d00001

diff --git a/build_postgis25_el6/pgdg-redhat-repo-latest.noarch.rpm b/build_postgis25_el6/pgdg-redhat-repo-latest.noarch.rpm
new file mode 100644
index 0000000000000000000000000000000000000000..9b3560ddc81f35620395fa5f4ea5b4d80692d7d1
GIT binary patch
literal 5888
zcmbVQ3pkWn`2WTwLXoI+(N}7tHN!A7hUkKFi4qZ_n#(t1n49@NmuOQeNh#@Oi(<D{
zcamf)m0Fh~D%PS4T9Kj@kre-P#@Ft)|7V})-~T+%ncw++=RNOv&wI}Mo<rA}*N;>Y
zP$+UCUr1G8{16TSKrW*)tZ0^0ChYsa77C*NZ_(Z7UQozy8UR~CoewH(*Mh1CCe|i7
z0K^sWF#t!6v=J~?^#y3Ffl7c1c_%<PJ{nXoUbTzli2%WP)i(g4{C!X<iA&UwaVp3t
zb(P@cx9N!1XuatZ9=14ByFdIk4#}A49d78=W-{%&`Na<>o6P&ryyX*$WVSY(h_-q1
z^0c|fOyh^+T2s2J3?498HkK?KfsKI8vBmfTjt!T?#@Jjwoh4w{GBJ!{!?wiObZamt
zD2D7Qp&F9j7ggqgO9q}jLxMN`w;k_vk<3FDV{0auv5vVt_3ybs4d%F5to20F$EsZ&
zcX!*VwW~J>WU-Sr-FTi_5{DquKY$68J{%q%P62J;0|fbppV<ha`51g!04ng4W+gx<
z!v|FpR9L?F75Z6)<Q)JZA5Zd^B%efb==af}P9{0@JLFuFzXk~X4)+!6hx-8a)sy@!
zK-k|)@;-pDAFc<=Lj?LL@Hj&L2_WdF=#u<1$>)-Mh~$<dTn*|5mBI!Hbf`hy04dHS
zhqglQPI4`PP~MB=@EijFP=ZLVL-Hn)!*dDcTS*S>g7V!YhdzdUnB)ckfek8S0fP0Y
z83F|3RiM4lzKH;Vyox<Qum@_B$o>$3V4Ru}*}sY8(C<KA70v_uO-E3b0TAkk>jwH&
zp*|3YYPJBOycfysM!1><$sI@dC>XQ)K;8u)7(WW`Gqlf@<ZxdgcLNCYX#g1|_aEuk
z0N<4M2ax^HKDeGhvL6Kq^{)m9$A^#{`Wfib*Z>gf4<`E)Nxp{U1tf>(46IwD6(C$M
ze}rp7J&<E0=a5`LawrG;#UzK{AtwNW`878Ig!4y`d>6?h0Rnq9(?}jg_UDp3n&j6;
z`1pM!F9%3*LjIjk5tvUACgLT-384b>S>b_txj4I^-d>(K6%B}xpxz+s;vzz(SdTi%
zqymvJLct+KGASyMDL^M5b>$GK1?q%JiRC`X$`BEb$~n9+ju1n6GAY3kNpW;N&;!VS
z3|=fHFoj$p!ZFlCB#nqRCzY9Nain~dBgSPY5rUyEUM^@Dwq7~!UpCSZm_fs2p&}{|
zSRlh$)Mz$~%3@IELT-de4Bb4f>hIMdzEWI{@k9a<#z#U3LXO*6SOD{AV3E)Pc(|A*
zQwR|;Gz5{#I0_y-8Ol^O>N<i<)LYcG`S|AJ@Ef9>8_a(=IJxUK!sOX-`CO2NSu7SG
zW3cELondJSva^+?4WGeh2-rMJCX2~qvN&uumutn~+1LoIm|QlKWo2p2XCPc#jLoET
z=@^^C=kXbAE`v_T7)&~y!DaES_%@g&htFa#fp#_%<JodS!`eo`<nwq8I$ywoC-Lh-
zQOINj@}EEdJ`3dCO2ZXAnnErCx<D@ftBmZQ>Awe={qG|+Vgv{{O>m&K{#h+Bf@ks9
zZ7#+*IEMVEUSNV)#5Hx2N#tN(aE!l1B*vC;Bp7ankbUrrvq*^H#NXe%IP1kSj#3zR
z<wRm$3QQo1{%Z)??S}ium?6s34_*`2G)o$TN=Fzp7I<AiguhIhm9otS5d!vlr{B$>
z%Z3YsF5SKvlw-ay=v?DXXDm`7lAtcPuSxm0uf?GDeC3CQ!U!opA_g9$`6v}7pDf=X
z%s{?D*!o+9t-e7Rp`weW9IhBcBk5KsPAHr35oV6Uz!ZUfkws!CAH#VHkzAP*WC9cl
zpi;O^G%YIXtdPl3JVGv)DF|ic`tU>`PC@+fMuHtR1zJKe9)a>jI7}EI@G!m^7`lkh
z2NPSP1lV4YRH#%uGP8sehK<Z400#g^B{GFF+2A6a0LsxQ5fOrVyDs)XWl~@UScf+z
zfu>40p&)5RVhUWDz!WmDcOa`kElQJ7kyM##lxt9a<=|)(CKi8#4s%qFfjKw|kt_mN
zTB#tEHaLs$znuB?nnVN&vL;xiSPU%yhX@nP<Px|Pc?gIR8tMg9I)lTEdV#zOjadm2
zq7;i7@dBA|&4KM87egm1vn~gyBV7;DG;lAWkO51S5j>JC=~n-Y-Y*One`%3Y^sl5y
z2BgRqDP{SU6v==T*&30uW&Km?3&X`<TBH>7D=CrzDY8XMF}{)_8IXc+4_H9z`Kp5Z
zAKt0TY!2>FM3aonZ~vPDD*68vXp;&^UsR!7h=5y`3JxH3>EZw?ywd);9xB*A8a#-I
zGHc4iL>7OyNCo5<cz;1joW{36sLQQTst~2hMRE+Ku7Zbvx=L<NbzZw<x%W!9B>`)F
zmiu};Ep`B60xX(`DI*sL1VlJ5j0(b$0O1JYgi4ij6dZ{Ij?1as2!Q}oP;pTV=D<Ly
z5*GX+BBYpu5R+mG5f9<XMKUBh2C*V<%`bnoDQ{A$PzoP1|0-}lV4)z3e4O0eK%_?#
z2w$X7PQQMn@4tTG{we>K7#{w#3AFV-+r;>T$DLNopiY(wGJ^sixN2Umtmf(cns_iW
zY0MKfuGK(<c4$}4nTP94NA272$bO*2cS^%mN%y=zFRosh?HCcUBSv@b{7PC$<YTAM
z2|rvjXsK*8plnXGv>)#FPgU*Ly!JynwlCyRegE^evyNL;RlawrC=IwZ&bRYut?KkE
zG+A7)mzn$CK6x6CpnELVXh>LlEWrHUf>X0&j;3fvFe}=AJha32&z7IYHs}4acijr3
zPZJ8Z<mrCineaB4efh)*O7evE9@Ej9#~z%ktgi9kgiCa*i7<K7j%eXouNhD8{B)wN
zI!-qa>-8y-3aUE}6kbZFP^^>LFE4K>-aMZEPNn|$9D}W0k@E7u)dy?K%QwbWY7Y3@
z1^MR6$`0KTXh$aAY}vomGslv3u&t=Gc$1r^`a^N~;>2l%DLofY)~1I4I%&=Dnx#kt
z)yl2^IH$`$SC8A!G-k79L-p2G{SPvZTn>wRusis5(}3eno#Omq)eODRz=RFQt@qHn
zCKNCO-46xd%D3F%U+jSCH@4Z))#8Q6=P$f-Qq!n7+3$V5Ym`Db*pt6+&#o24+Qx<y
zGr>^J<HmjI<ML$cNqM#!n`cdRU(CviYb@LuUKD1sG0?p#Eq;8#$@?7HQG8-)Og~He
zhQYL58-09|FWuH|&1K3~rd4#mI+Jv0VdqLa?~LEQ>WtEz7M)0Wb^%#?UTc1^EIcG2
zpsRuyf3N8z&EZ^0UD<%TU*`It7UX4)*#FJv&ik`JPhIuwUZ>PBc_8BZLiX!1Iv3Nz
zB}*_npBY9$Z%u-jCj#!=l*Fk>(toZX()Lfy?`<geBocqkL*gsC=QR8t{c)>dg8%6m
zM>`IezMNgHl2e-V-Y(U`FZS(B=htuA&rJL=SKr>@>i)?`Z|1*R(O43qWozL2EB5@b
z;QWmm!*>fp<P82KUQj_<lS6%2)kn>3mG`UbO3Ze=EL*Ql1f(8m-xlU!r!zO;y@}0&
ztj7&(+iNFHymg8`C1Fnz9XzM+TDR^59Vy;lg~r?)Y|0cSsKz@V*}Et5^v@Gx8_J#X
zl8^bR2TL1#+pbr(omsHu45PifG~25|rL8h$?jL!l^o-js>xa$zAipV!dg4&{=b}2p
zK|_hg&R3nf@mZ+novKeC13dO+W|sH5Hon@isn0e0)+*ayBGSWsWlMK!PPo=@vTK=r
z#uXD&z3<)@-PhX?9v5GwM%Zf)_B*ybSY6YXvr+5)_56KV+Cx?)46N?QuCXrRPKi1Z
zCXeMqi%egXT24sLys`wJf1xP$xP#8Nv*$GmP<Dl{;*htNgylEqfk*VgzECZJk<o?2
zQ(E5lx*fSG%t~!9+fJ`QqAat-eQ6cD(lRfU4mRx9&GayKaPQ8JpH#D<vMHyxebqUi
zSNUpZ>$9h=PQLTzkrhpQOMA=XwTDjJyNerZxfh+Vc9|KSJ=pWybNaJSh==<l(_d=d
z^~~64=;x?E{m#8G>y*Tr!l>_c{C_&^Gc~9`z%6u6iqkVB(5S}v7kOcF-IJ(~!Hyrt
z2}9rYE~|Pn`lYW{1}>a8e&sCcqf-{|i&cJ2t7zSDaEsP9=b0OM7EBA{%xiYN^K*^z
zPCqTEn3WgXYty=aFtR1Buq)ZgI-|<!$ylGMPXl$%>(Q6#iVkd!U6Zv<?CjrkpS8uc
zcEW;X!^9t*Y1CVz8bj|a(#Eepb-X`zxBl;0gIo97VgpP~Eo1GE7m8=GetYK^QZERq
z|6y;R_p6hBdV4gFElck|tzlHNvob2B>`p1BpWk%jl+7G&#X+6%UO#m(8+32DT#=p+
z9HMncS?-SMy_GrdT*t(Y+;`1)^N*ybF0lVatWw_`YxH()bLA|@ka)+=j@zou*sz9y
zi_h^_x^Jtk4o#VNAZ;H1Rv0T~bXht>h5N28-Ed9z!8!K)g$sVX=%7L;9=Q%$yym@l
z8gz8qv%Fng-+4<H%{*Rr?+DLmv#HR>jU}3OA9vb6ZQ02U`^B>Y?)shg)2pk0zGKiT
zAS3_W#bwQj237V%aPYmxb2~&X0c#u@SDfSH^+DU?p6b1d96h(k^1Xd?(OK*J@(Eej
z?UC8(14Hb1uPaICQSHpC-v*{$c|qJ)yKu>8rQp<c>rY8ng<B@2w~O3HEq^0TdfT#d
zde8dExGB?J$8;@d&z+Lmta^~zv(Ip&_GO{9U;OpG%sCyKj2t`WJwBDBslK`6266gC
z>D&T$eKn^A+rR6tP+O-+O$d=MGfuejG<0k3rz}cHlsn&SW_nSr!D3rE{Zm0)+?cq6
zZedi)&c>tdMaI6L%l>3nXJ>TQQp&MIp95cc-aYv;c_O8*B{}`{nELCN@}Iv;kkVo*
z*CpN6PHR=0<{C6qFj-)evwD-+l%Hc?9JUCVhHtEUI=c9ZB*&e<GjM+S!hrTT(~Qgq
zdHHHXddFRM&lMDIi0yr|bk;_*;N7ixXRoWz536N}vvTT&DC^r_(B3?dX{!6Djw?SK
zxIKTenNMomo9CrYCPAfk?ydY=XOc}Xn_HTHWVw2{@ZS|Ky*bc7<>^AVUnBdj{WzuV
zMdBWM`?|@F+b33=9@KK;1uT=C3+JpVsZq%-_1vD68ZdpsSaTvLz`Q*?e@>}muKnUm
zcU_tfFxfx6o7C*@)n?o&*RMEsBXHdA87|#*DRz&SHfu==f9TS;GpN0J=^5k9PwAUG
zw(i+vm2fhtl)pzkJJWIY?_#`AP`0POGr~JgB>W@8uxycJdzqX2_1=%yiOgNKc7w|a
zqmsUXU0u4~^4CLScE#%U?8#j{tbSg1?Wso3^Uf<(K35zh@Z&!}QOj@XSoETHlOS`Q
zhEvjqg!-SyA4sU|k9BhFz~XkNCy$Oln%w6#G}+KBB)p)>K5$IvO?<&Nf#<xQYsQ9C
zoM&oeSL;dG*1z3VgyFNzjqs~uZnLxXT|d?y*f{SI!+xLIu+wv?D|c<oRq&se&pJhl
z&k|$5l1V8aXRVmadFWPI)O2tCI+u?ZXJxyas34T=aUZ}dCg=~dzJiXXsmceDRzTqY
E0LwM7T>t<8

literal 0
HcmV?d00001

diff --git a/build_postgis25_el6/run_docker_build.sh b/build_postgis25_el6/run_docker_build.sh
new file mode 100755
index 000000000..f8b2a32e0
--- /dev/null
+++ b/build_postgis25_el6/run_docker_build.sh
@@ -0,0 +1,56 @@
+#!/bin/bash
+#
+# Use a container to build PostGIS 2.5 for PostgreSQL 2.5 on CentOS/RHEL 6
+#
+
+SUDO=${SUDO:-sudo}
+
+if [ "$(id -u)" -eq 0 ]
+then
+    echo "Do not run this script as root, run it as the owner of the"
+    echo "checked out pgrpms git tree."
+    exit 1
+fi
+
+if ! [ -e rpm/redhat/common/Makefile.global ]
+then
+    echo "rpm/redhat/common/Makefile.global not found"
+    echo "Run from the root of the pgrpms directory"
+    echo "(cwd is now $(pwd))"
+    exit 1
+fi
+
+if ! test -O "."
+then
+    echo "$(pwd) is now owned by current user, run as user who owns it"
+    exit 1
+fi
+
+set -e -u
+
+if [ -n "$(which getenforce 2>/dev/null)" ]
+then
+    if [ "$(getenforce)" = "Enforcing" ]; then
+	echo "-------------------------------------------------------"
+	echo "WARNING: SELinux is in enforcing mode and may interfere"
+	echo "with Docker bind mounts unless you relabel the tree."
+	echo
+	echo "Consider running 'setenforce 0' for the build then"
+	echo "re-enabling SELinux with 'setenforce 1' afterwards."
+	echo "-------------------------------------------------------"
+    else
+	echo "SELinux detected: $(getenforce)";
+    fi
+fi
+
+sudo docker build -t build_postgis25_el6 \
+    --build-arg PGRPMS_UID=$(id -u) --build-arg PGRPMS_GID=$(id -g) \
+    --build-arg PGRPMS_USER=$(id -un) --build-arg PGRPMS_GROUP=$(id -gn) \
+    build_postgis25_el6
+
+sudo docker rm buildit >&/dev/null || true
+
+sudo docker run --rm -v `pwd`:/pgrpms -it --name buildit \
+    build_postgis25_el6:latest
+
+find rpm/redhat/ -name \*.rpm
diff --git a/rpm/redhat/12/geos36/EL-6 b/rpm/redhat/12/geos36/EL-6
new file mode 120000
index 000000000..4d466ba64
--- /dev/null
+++ b/rpm/redhat/12/geos36/EL-6
@@ -0,0 +1 @@
+../../master/geos36/EL-6
\ No newline at end of file
diff --git a/rpm/redhat/common/Makefile.global b/rpm/redhat/common/Makefile.global
index 5281a2b9d..c8b4ef5cb 100644
--- a/rpm/redhat/common/Makefile.global
+++ b/rpm/redhat/common/Makefile.global
@@ -18,7 +18,7 @@ prep:
 	if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
 
 	# Update spec file, patches, etc, before running spectool:
-	git pull
+	if [ -z "$(NO_GIT)" ]; then git pull; fi
 
 	# Use spectool to download source files, especially tarballs.
 	spectool -g -S $(SPECFILE)
diff --git a/rpm/redhat/common/Makefile.global-PG12 b/rpm/redhat/common/Makefile.global-PG12
index d19f6c7a8..00255a67f 100644
--- a/rpm/redhat/common/Makefile.global-PG12
+++ b/rpm/redhat/common/Makefile.global-PG12
@@ -20,7 +20,7 @@
 prep12:
 	if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
 	# Update spec file, patches, etc, before running spectool:
-	git pull
+	if [ -z "$(NO_GIT)" ]; then git pull; fi
 	# Use spectool to download source files, especially tarballs.
 	spectool -g -S --define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" $(SPECFILE)
 
@@ -39,21 +39,21 @@ srpm12: prep12
 	--define "_builddir ." --define "_srcrpmdir ." --sign \
 	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
 	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12"  --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
+	--define "_rpmdir ." --define "dist $(DIST)" -bs $(SPECFILE)
 
 bfsrpm12: prep12
 	rpmbuild --define "_sourcedir ." --define "_specdir ." \
 	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm12/SRPMS" --sign \
 	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
 	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12"  --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
+	--define "_rpmdir ." --define "dist $(DIST)" -bs $(SPECFILE)
 
 bfnosignsrpm12: prep12
 	rpmbuild --define "_sourcedir ." --define "_specdir ." \
 	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
 	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm12/SRPMS" \
 	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12"  --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
+	--define "_rpmdir ." --define "dist $(DIST)" -bs $(SPECFILE)
 
 rpm12: prep12
 	rpmbuild --define "_sourcedir $(PWD)" \
@@ -80,7 +80,7 @@ noprepbuild12:
 	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm12/SRPMS" --sign \
 	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
 	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
+	--define "_rpmdir ." --define "dist $(DIST)" -bs $(SPECFILE)
 
 	rpmbuild --define "_sourcedir $(PWD)" \
 	--define "_specdir $(PWD)" \
@@ -106,5 +106,5 @@ noprepsrpm12:
 	--define "_builddir ." --define "_srcrpmdir ." \
 	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
 	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
+	--define "_rpmdir ." --define "dist $(DIST)" -bs $(SPECFILE)
 
diff --git a/rpm/redhat/master/postgis25/master/postgis25.spec b/rpm/redhat/master/postgis25/master/postgis25.spec
index 17f16bb57..3f32eae45 100644
--- a/rpm/redhat/master/postgis25/master/postgis25.spec
+++ b/rpm/redhat/master/postgis25/master/postgis25.spec
@@ -4,13 +4,13 @@
 %global postgisprevmajorversion 2.4
 %global sname	postgis
 
-%global geosversion	38
+%global geosversion	36
 %global gdalversion	30
-%global projversion	62
+%global projversion	49
 
 %global	geosinstdir	/usr/geos%{geosversion}
 %global	projinstdir	/usr/proj%{projversion}
-%global	gdalinstdir	/usr/gdal%{gdalversion}
+%global	gdalinstdir	/usr/
 
 %global	gdalminorversion	3.0.2
 
@@ -28,7 +28,8 @@
 %if 0%{?fedora} >= 27 || 0%{?rhel} >= 6 || 0%{?suse_version} >= 1315
 %ifnarch ppc64 ppc64le
 # TODO
-%{!?sfcgal:%global     sfcgal 1}
+# disabled for EL-6
+%{!?sfcgal:%global     sfcgal 0}
 %else
 %{!?sfcgal:%global     sfcgal 0}
 %endif
@@ -56,7 +57,7 @@ Patch1:		%{sname}%{postgiscurrmajorversion}-%{postgismajorversion}.1-el6pragma.p
 
 URL:		http://www.postgis.net/
 
-BuildRequires:	postgresql%{pgmajorversion}-devel, geos%{geosversion}-devel >= 3.8.0, pcre-devel
+BuildRequires:	postgresql%{pgmajorversion}-devel, geos%{geosversion}-devel >= 3.6.0, pcre-devel
 %if 0%{?suse_version}
 %if 0%{?suse_version} >= 1315
 BuildRequires:	libjson-c-devel libproj-devel
@@ -89,7 +90,7 @@ BuildRequires:	advance-toolchain-%{atstring}-devel
 %endif
 
 Requires:	postgresql%{pgmajorversion} postgresql%{pgmajorversion}-contrib
-Requires:	geos%{geosversion} >= 3.8.0 proj%{projversion} xerces-c
+Requires:	geos%{geosversion} >= 3.6.0 proj%{projversion} xerces-c
 %if 0%{?rhel} && 0%{?rhel} < 6
 Requires:	hdf5 < 1.8.7
 %else
@@ -241,7 +242,7 @@ LDFLAGS="$LDFLAGS -L%{geosinstdir}/lib64 -L%{projinstdir}/lib64"; export LDFLAGS
 %endif
 	--enable-rpath --libdir=%{pginstdir}/lib \
 	--with-geosconfig=/%{geosinstdir}/bin/geos-config \
-	--with-gdalconfig=%{gdalinstdir}/bin/gdal-config \
+	--with-gdalconfig=%{gdalinstdir}/bin/gdal-config-64 \
 	--with-projdir=%{projinstdir}
 
 SHLIB_LINK="$SHLIB_LINK" %{__make} LPATH=`%{pginstdir}/bin/pg_config --pkglibdir` shlib="%{sname}-%{postgismajorversion}.so"
@@ -385,6 +386,9 @@ fi
 %endif
 
 %changelog
+* Mon Dec 16 2019 Craig Ringer <craig.ringer@2ndquadrant.com>
+- Rebuild for PostgreSQL 12 on CentOS 6 using GEOS 3.6
+
 * Thu Sep 26 2019 Devrim Gündüz <devrim@gunduz.org> 2.5.3-6
 - Rebuild for GEOS 3.8.0, Proj 6.2.1 and GDAL 3.0.2
 
diff --git a/rpm/redhat/master/proj49/EL-6/Makefile b/rpm/redhat/master/proj49/EL-6/Makefile
new file mode 100644
index 000000000..7d7c98764
--- /dev/null
+++ b/rpm/redhat/master/proj49/EL-6/Makefile
@@ -0,0 +1,17 @@
+#################################
+# RPM-specific Makefile		#
+# https://yum.postgresql.org	#
+#                         	#
+# Devrim Gunduz			#
+# devrim@gunduz.org		#
+#################################
+
+# Predefined values
+
+ARCH=`rpm --eval "%{_arch}"`
+DIR=`pwd`
+DIST=.rhel6
+SPECFILE="proj49.spec"
+
+# Now, include global Makefile
+include ../../../common/Makefile.global
diff --git a/rpm/redhat/master/proj49/EL-6/proj-4.8.0-removeinclude.patch b/rpm/redhat/master/proj49/EL-6/proj-4.8.0-removeinclude.patch
new file mode 120000
index 000000000..d78b7fff2
--- /dev/null
+++ b/rpm/redhat/master/proj49/EL-6/proj-4.8.0-removeinclude.patch
@@ -0,0 +1 @@
+../master/proj-4.8.0-removeinclude.patch
\ No newline at end of file
diff --git a/rpm/redhat/master/proj49/EL-6/proj49-pgdg-libs.conf b/rpm/redhat/master/proj49/EL-6/proj49-pgdg-libs.conf
new file mode 120000
index 000000000..ca62b05d2
--- /dev/null
+++ b/rpm/redhat/master/proj49/EL-6/proj49-pgdg-libs.conf
@@ -0,0 +1 @@
+../master/proj49-pgdg-libs.conf
\ No newline at end of file
diff --git a/rpm/redhat/master/proj49/EL-6/proj49.spec b/rpm/redhat/master/proj49/EL-6/proj49.spec
new file mode 120000
index 000000000..2135b70fe
--- /dev/null
+++ b/rpm/redhat/master/proj49/EL-6/proj49.spec
@@ -0,0 +1 @@
+../master/proj49.spec
\ No newline at end of file
diff --git a/rpm/redhat/master/proj49/master/Makefile b/rpm/redhat/master/proj49/master/Makefile
new file mode 100644
index 000000000..f2aa7d79e
--- /dev/null
+++ b/rpm/redhat/master/proj49/master/Makefile
@@ -0,0 +1,17 @@
+#################################
+# RPM-specific Makefile		#
+# https://yum.postgresql.org	#
+#                         	#
+# Devrim Gunduz			#
+# devrim@gunduz.org		#
+#################################
+
+# Predefined values
+
+ARCH=`rpm --eval "%{_arch}"`
+DIR=`pwd`
+DIST=.f42
+SPECFILE="proj49.spec"
+
+# Now, include global Makefile
+include ../../../common/Makefile.global
diff --git a/rpm/redhat/master/proj49/master/proj-4.8.0-removeinclude.patch b/rpm/redhat/master/proj49/master/proj-4.8.0-removeinclude.patch
new file mode 100644
index 000000000..dd0898589
--- /dev/null
+++ b/rpm/redhat/master/proj49/master/proj-4.8.0-removeinclude.patch
@@ -0,0 +1,10 @@
+--- src/jniproj.c.old	2012-04-21 00:01:12.286146452 +0300
++++ src/jniproj.c	2012-04-21 00:01:18.128146582 +0300
+@@ -49,7 +49,6 @@
+ #include <math.h>
+ #include <string.h>
+ #include "projects.h"
+-#include "org_proj4_PJ.h"
+ #include <jni.h>
+ 
+ #define PJ_FIELD_NAME "ptr"
diff --git a/rpm/redhat/master/proj49/master/proj49-pgdg-libs.conf b/rpm/redhat/master/proj49/master/proj49-pgdg-libs.conf
new file mode 100644
index 000000000..d85b63a96
--- /dev/null
+++ b/rpm/redhat/master/proj49/master/proj49-pgdg-libs.conf
@@ -0,0 +1 @@
+/usr/proj49/lib/
diff --git a/rpm/redhat/master/proj49/master/proj49.spec b/rpm/redhat/master/proj49/master/proj49.spec
new file mode 100644
index 000000000..b53989a59
--- /dev/null
+++ b/rpm/redhat/master/proj49/master/proj49.spec
@@ -0,0 +1,239 @@
+%global sname proj
+%global projinstdir /usr/%{sname}49
+
+%ifarch ppc64 ppc64le
+# Define the AT version and path.
+%global atstring	at10.0
+%global atpath		/opt/%{atstring}
+%endif
+
+Name:		%{sname}49
+Version:	4.9.3
+Release:	3%{?dist}.1
+Epoch:		0
+Summary:	Cartographic projection software (PROJ.4)
+
+License:	MIT
+URL:		http://trac.osgeo.org/proj
+Source0:	http://download.osgeo.org/%{sname}/%{sname}-%{version}.tar.gz
+Source1:	http://download.osgeo.org//proj/proj-datumgrid-1.5.zip
+Source2:	%{name}-pgdg-libs.conf
+
+Patch0:		proj-4.8.0-removeinclude.patch
+
+BuildRequires:	libtool
+
+%ifarch ppc64 ppc64le
+BuildRequires:	advance-toolchain-%{atstring}-devel
+%endif
+
+%ifarch ppc64 ppc64le
+AutoReq:	0
+Requires:	advance-toolchain-%{atstring}-runtime
+%endif
+
+%package devel
+Summary:	Development files for PROJ.4
+Requires:	%{name} = %{version}-%{release}
+%ifarch ppc64 ppc64le
+AutoReq:	0
+Requires:	advance-toolchain-%{atstring}-runtime
+%endif
+
+%package nad
+Summary:	US, Canadian, French and New Zealand datum shift grids for PROJ.4
+Requires:	%{name} = %{version}-%{release}
+%ifarch ppc64 ppc64le
+AutoReq:	0
+Requires:	advance-toolchain-%{atstring}-runtime
+%endif
+
+%package epsg
+Summary:	EPSG dataset for PROJ.4
+Requires:	%{name} = %{version}-%{release}
+%ifarch ppc64 ppc64le
+AutoReq:	0
+Requires:	advance-toolchain-%{atstring}-runtime
+%endif
+
+%package static
+Summary:	Development files for PROJ.4
+Requires:	%{name}-devel%{?_isa} = %{version}-%{release}
+%ifarch ppc64 ppc64le
+AutoReq:	0
+Requires:	advance-toolchain-%{atstring}-runtime
+%endif
+
+%description
+Proj and invproj perform respective forward and inverse transformation of
+cartographic data to or from cartesian data with a wide range of selectable
+projection functions. Proj docs: http://www.remotesensing.org/dl/new_docs/
+
+%description devel
+This package contains libproj and the appropriate header files and man pages.
+
+%description nad
+This package contains additional US and Canadian datum shift grids.
+
+%description epsg
+This package contains additional EPSG dataset.
+
+%description static
+This package contains libproj static library.
+
+%prep
+%setup -q -n %{sname}-%{version}
+
+# disable internal libtool to avoid hardcoded r-path
+for makefile in `find . -type f -name 'Makefile.in'`; do
+sed -i 's|@LIBTOOL@|%{_bindir}/libtool|g' $makefile
+done
+
+# Prepare nad
+cd nad
+unzip %{SOURCE1}
+cd ..
+# fix shebag header of scripts
+for script in `find nad/ -type f -perm -a+x`; do
+sed -i -e '1,1s|:|#!/bin/bash|' $script
+done
+
+%build
+# fix version info to respect new ABI
+sed -i -e 's|5\:4\:5|6\:4\:6|' src/Makefile*
+
+%ifarch ppc64 ppc64le
+	CFLAGS="${CFLAGS} $(echo %{__global_cflags} | sed 's/-O2/-O3/g') -m64 -mcpu=power8 -mtune=power8 -I%{atpath}/include"
+	CXXFLAGS="${CXXFLAGS} $(echo %{__global_cflags} | sed 's/-O2/-O3/g') -m64 -mcpu=power8 -mtune=power8 -I%{atpath}/include"
+	LDFLAGS="-L%{atpath}/%{_lib}"
+	CC=%{atpath}/bin/gcc; export CC
+%endif
+LDFLAGS="-Wl,-rpath,/usr/proj49/lib64 ${LDFLAGS}" ; export LDFLAGS
+SHLIB_LINK="$SHLIB_LINK -Wl,-rpath,/usr/proj49/lib" ; export SHLIB_LINK
+
+#./configure --exec-prefix=/usr/proj49 --libdir=/usr/proj49/lib --without-jni
+./configure --prefix=%{projinstdir} --without-jni
+#make OPTIMIZE="$RPM_OPT_FLAGS" %{?_smp_mflags}
+%{__make} %{?_smp_mflags}
+
+%install
+%{__rm} -rf %{buildroot}
+%make_install
+%{__install} -d %{buildroot}%{projinstdir}/share/%{sname}
+%{__install} -d %{buildroot}%{projinstdir}/share/doc/
+%{__install} -p -m 0644 nad/pj_out27.dist nad/pj_out83.dist nad/td_out.dist %{buildroot}%{projinstdir}/share/%{sname}
+%{__install} -p -m 0755 nad/test27 nad/test83 nad/testvarious %{buildroot}%{projinstdir}/share/%{sname}
+%{__install} -p -m 0644 nad/epsg %{buildroot}%{projinstdir}/share/%{sname}
+%{__install} -p -m 0644 NEWS AUTHORS COPYING README ChangeLog %{buildroot}%{projinstdir}/share/doc/
+
+# Install linker config file:
+%{__mkdir} -p %{buildroot}%{_sysconfdir}/ld.so.conf.d/
+%{__install} %{SOURCE2} %{buildroot}%{_sysconfdir}/ld.so.conf.d/
+
+%check
+pushd nad
+# set test enviroment for porj
+export PROJ_LIB=%{buildroot}%{projinstdir}/share/%{sname}
+export LD_LIBRARY_PATH=$LD_LIBRARY_PATH%{buildroot}%{projinstdir}/lib
+# run tests for proj
+./test27      %{buildroot}%{projinstdir}/bin/%{sname} || exit 0
+./test83      %{buildroot}%{projinstdir}/bin/%{sname} || exit 0
+./testntv2    %{buildroot}%{projinstdir}/bin/%{sname} || exit 0
+./testvarious %{buildroot}%{projinstdir}/bin/%{sname} || exit 0
+popd
+
+%clean
+%{__rm} -rf %{buildroot}
+
+%post
+%ifarch ppc64 ppc64le
+%{atpath}/sbin/ldconfig
+%else
+/sbin/ldconfig
+%endif
+
+%postun
+%ifarch ppc64 ppc64le
+%{atpath}/sbin/ldconfig
+%else
+/sbin/ldconfig
+%endif
+
+%files
+%defattr(-,root,root,-)
+%doc %{projinstdir}/share/doc/*
+%{projinstdir}/bin/*
+%{projinstdir}/share/man/man1/*.1
+%{projinstdir}/lib/libproj.so.12*
+%config(noreplace) %attr (644,root,root) %{_sysconfdir}/ld.so.conf.d/%{name}-pgdg-libs.conf
+
+%files devel
+%defattr(-,root,root,-)
+%{projinstdir}/share/man/man3/*.3
+%{projinstdir}/include/*.h
+%{projinstdir}/lib/*.so
+%{projinstdir}/lib/*.a
+#%attr(0755,root,root) %{projinstdir}/pkgconfig/%{sname}.pc
+%exclude %{projinstdir}/lib/libproj.a
+%exclude %{projinstdir}/lib/libproj.la
+
+%files static
+%defattr(-,root,root,-)
+%{projinstdir}/lib/libproj.a
+%{projinstdir}/lib/libproj.la
+
+%files nad
+%defattr(-,root,root,-)
+%doc nad/README
+%attr(0755,root,root) %{projinstdir}/share/%{sname}/test27
+%attr(0755,root,root) %{projinstdir}/share/%{sname}/test83
+%attr(0755,root,root) %{projinstdir}/share/%{sname}/testvarious
+%attr(0755,root,root) %{projinstdir}/lib/pkgconfig/%{sname}.pc
+%exclude %{projinstdir}/share/%{sname}/epsg
+%{projinstdir}/share/%{sname}
+
+%files epsg
+%defattr(-,root,root,-)
+%doc nad/README
+%attr(0644,root,root) %{projinstdir}/share/%{sname}/epsg
+
+%changelog
+* Mon Oct 15 2018 Devrim Gündüz <devrim@gunduz.org> - 0:4.9.3-3.1
+- Rebuild against PostgreSQL 11.0
+
+* Tue Nov 28 2017 Devrim Gündüz <devrim@gunduz.org> - 4.9.3-3
+- Fix linker config file contents. Per report from Daniel Farina.
+
+* Thu Nov 23 2017 Devrim Gündüz <devrim@gunduz.org> - 4.9.3-2
+- Add a linker config file to satisfy GDAL and other packages
+  which we use while building PostGIS.
+
+* Tue Nov 21 2017 Devrim Gündüz <devrim@gunduz.org> 4.9.3-1
+- Update to 4.9.3
+
+* Mon Apr 24 2017 Devrim Gündüz <devrim@gunduz.org> 4.9.2-1
+- Update to 4.9.2
+
+* Wed Mar 11 2015 Devrim Gündüz <devrim@gunduz.org> 4.9.1-1
+- Update to 4.9.1
+- track soname so bumps are not a suprise.
+- -devel: include .pc file here (left copy in -nad too)
+
+* Thu Jul 26 2012 Devrim Gündüz <devrim@gunduz.org> - 0:4.8.0-2
+- Add --without-jni to configure, for clean build..
+
+* Wed Apr 04 2012 - Devrim Gündüz <devrim@gunduz.org> - 0:4.8.0-1
+- Update to 4.8.0
+
+* Thu Dec 10 2009 - Devrim Gündüz <devrim@gunduz.org> - 0:4.7.0-1
+- Update to 4.7.0
+- Update proj-datumgrid to 1.5
+- Fix attr issue for epsg package.
+
+* Tue Dec 2 2008 - Devrim Gündüz <devrim@gunduz.org> - 0:4.6.1-1
+- Update to 4.6.1
+- Update URLs
+
+* Thu Apr 3 2008 - Devrim Gündüz <devrim@gunduz.org> - 0:4.6.0-1
+- Initial build for yum.postgresql.org, based on Fedora/EPEL spec.
+
-- 
2.23.0

